@@ -4,5 +4,8 @@ mod quiz;
 mod regex_handle;
 mod request;
 
+#[cfg(feature = "emacs")]
+mod emacs_mode;
+
 pub use quiz::*;
 pub use request::set_token;
